@@ -7,11 +7,8 @@
 ## -----------------------------------------------------------------------------
 
 runifSphere = function(dimension,N,radius) {
-
-    tmp = rnorm(dimension*N, mean=0, sd=1)
-    dim(tmp) = c(dimension,N)
-    tmp = apply(tmp, 2, function(x) {dim(x) = c(1,length(x));x/norm(x,"F")*(runif(1,min=0,max=1))^(1/dimension)*radius})
-
+    tmp = matrix(rnorm(dimension*N), dimension, N)
+    tmp <- t(tmp)*c(1/sqrt(rep(1,dim(tmp)[1])%*%tmp^2))*runif(N)^(1/dimension)*radius
+    colnames(tmp) <- rep(c('x', 'y'), length.out = dimension)
     return(tmp)
-}
-
+}
\ No newline at end of file
